@@ -18,7 +18,7 @@
 static void usage()
 {
 	fprintf (stderr,"chbind version %s\n",VERSION);
-	fprintf (stderr,"chbind [ --silent ] [ --ip ip_num ] command argument\n");
+	fprintf (stderr,"chbind [ --silent ] [ --ip ip_num ] [ --bcast broadcast ] command argument\n");
 	exit (-1);
 }
 
